.. -*- rst -*-

Authors
-------
This software was written and packaged by Lev Givon [1]_. It was inspired by 
ipython-sql, by Catherine Devlin [2]_.

ICypher is developed independently of (and hence not officially endorsed by) Neo 
Technology, Inc.

.. [1] http://www.columbia.edu/~lev/
.. [2] https://github.com/catherinedevlin/ipython-sql
